import { IWebGLContextAttributes } from "./webgl-context-attributes";
export interface IUnityConfig {
    /**
     * The url to the build json file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    loaderUrl: string;
    /**
     * The url to the build data file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    dataUrl: string;
    /**
     * The url to the framework file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    frameworkUrl: string;
    /**
     * The url to the unity code file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    codeUrl: string;
    /**
     * The url where the streaming assets can be found. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    streamingAssetsUrl?: string;
    /**
     * The applications company name.
     * @public
     * @type {string}
     */
    companyName?: string;
    /**
     * The applications product name.
     * @public
     * @type {string}
     */
    productName?: string;
    /**
     * The applications product version.
     * @public
     * @type {string}
     */
    productVersion?: string;
    /**
     * This object allow you to configure WebGLRenderingContext creation options
     * which will be pass additional context attributes to the Unity canvas.
     * @see https://developer.mozilla.org/en-US/docs/Web/API/WebGLRenderingContext
     * @public
     * @type {IWebGLContextAttributes}
     */
    webglContextAttributes?: IWebGLContextAttributes;
}
//# sourceMappingURL=unity-config.d.ts.map