import { IWebGLContextAttributes } from "./webgl-context-attributes";
export interface IUnityInstanceParameters {
    /**
     * The url to the build data file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    dataUrl: string;
    /**
     * The url to the framework file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    frameworkUrl: string;
    /**
     * The url to the unity code file generated by Unity. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    codeUrl: string;
    /**
     * The url where the streaming assets can be found. When using a relative url,
     * keep in mind this is relative from the path where your html file is served.
     * @public
     * @type {string}
     */
    streamingAssetsUrl?: string;
    /**
     * The applications company name.
     * @public
     * @type {string}
     */
    companyName?: string;
    /**
     * The applications product name.
     * @public
     * @type {string}
     */
    productName?: string;
    /**
     * The applications product version.
     * @public
     * @type {string}
     */
    productVersion?: string;
    /**
     * The Canvas can appear too blurry on retina screens. The devicePixelRatio
     * determines how much extra pixel density should be added to allow for a
     * sharper image.
     * @see https://developer.mozilla.org/en-US/docs/Web/API/Window/devicePixelRatio
     * @public
     * @type {number}
     */
    devicePixelRatio?: number;
    /**
     * When disabling the match WebGL to canvas size flag, the canvas allows for
     * client side customization of the WebGL canvas target size instead of
     * requiring it to always match 1:1 with the High DPI CSS size of the canvas.
     * Supported since Unity 2021.1b
     * @see https://issuetracker.unity3d.com/issues/webgl-builds-dont-allow-separate-control-on-canvas-render-buffer-size
     * @public
     * @type {boolean}
     */
    matchWebGLToCanvasSize?: boolean;
    /**
     * This object allow you to configure WebGLRenderingContext creation options
     * which will be pass additional context attributes to the Unity canvas.
     * @see https://developer.mozilla.org/en-US/docs/Web/API/WebGLRenderingContext
     * @public
     * @type {IWebGLContextAttributes}
     */
    webglContextAttributes?: IWebGLContextAttributes;
    /**
     * When assigned this method will intercept all incomming messages from the
     * Unity Module into the console. These messages will contain both of the
     * internal information messages as well as the debuggers log messages.
     * @public
     * @type {Function}
     */
    print?: (message: string) => void;
    /**
     * When assigned this method will intercept all incomming error logs from the
     * Unity Module into the console. These messages will contain both of the
     * runtime problems as well as the jslib and javascript errors thrown by the
     * Unity Instance.
     * @public
     * @type {Function}
     */
    printErr?: (message: string) => void;
}
//# sourceMappingURL=unity-instance-parameters.d.ts.map